=== modified file 'drizzled/session.h'
--- drizzled/session.h	2009-05-21 00:57:05 +0000
+++ drizzled/session.h	2009-05-21 16:13:03 +0000
@@ -142,6 +142,10 @@
   uint32_t net_wait_timeout;
   uint32_t net_write_timeout;
   bool optimizer_prune_level;
+  bool log_warnings;
+  bool engine_condition_pushdown;
+  bool keep_files_on_create;
+
   uint32_t optimizer_search_depth;
   /*
     Controls use of Engine-MRR:
@@ -152,10 +156,10 @@
   uint32_t optimizer_use_mrr;
   /* A bitmap for switching optimizations on/off */
   uint32_t optimizer_switch;
+  uint32_t div_precincrement;
   uint64_t preload_buff_size;
   uint32_t read_buff_size;
   uint32_t read_rnd_buff_size;
-  uint32_t div_precincrement;
   size_t sortbuff_size;
   uint32_t thread_handling;
   uint32_t tx_isolation;
@@ -168,14 +172,10 @@
   uint32_t query_prealloc_size;
   uint32_t trans_alloc_block_size;
   uint32_t trans_prealloc_size;
-  bool log_warnings;
   uint64_t group_concat_max_len;
   /* TODO: change this to my_thread_id - but have to fix set_var first */
   uint64_t pseudo_thread_id;
 
-  bool engine_condition_pushdown;
-  bool keep_files_on_create;
-
   StorageEngine *storage_engine;
 
   /* Only charset part of these variables is sensible */

=== modified file 'drizzled/table_share.h'
--- drizzled/table_share.h	2009-05-10 00:19:28 +0000
+++ drizzled/table_share.h	2009-05-21 16:13:03 +0000
@@ -33,6 +33,15 @@
   /** Category of this table. */
   enum_table_category table_category;
 
+  uint32_t open_count;			/* Number of tables in open list */
+
+  /* The following is copied to each Table on OPEN */
+  Field **field;
+  Field **found_next_number_field;
+  Field *timestamp_field;               /* Used only during open */
+  KEY  *key_info;			/* data of keys in database */
+  uint	*blob_field;			/* Index to blobs in Field arrray*/
+
   /* hash of field names (contains pointers to elements of field array) */
   HASH	name_hash;			/* hash of field names */
   MEM_ROOT mem_root;
@@ -44,12 +53,6 @@
   TableShare *next,		/* Link to unused shares */
     **prev;
 
-  /* The following is copied to each Table on OPEN */
-  Field **field;
-  Field **found_next_number_field;
-  Field *timestamp_field;               /* Used only during open */
-  KEY  *key_info;			/* data of keys in database */
-  uint	*blob_field;			/* Index to blobs in Field arrray*/
 
   unsigned char	*default_values;		/* row with default values */
   LEX_STRING comment;			/* Comment about table */
@@ -73,32 +76,27 @@
   LEX_STRING normalized_path;		/* unpack_filename(path) */
   LEX_STRING connect_string;
 
-  /*
-     Set of keys in use, implemented as a Bitmap.
-     Excludes keys disabled by ALTER Table ... DISABLE KEYS.
-  */
-  key_map keys_in_use;
-  key_map keys_for_keyread;
-  ha_rows min_rows, max_rows;		/* create information */
   uint32_t   avg_row_length;		/* create information */
   uint32_t   block_size;                   /* create information */
-  uint32_t   version, mysql_version;
+  uint32_t   mysql_version;
+  uint32_t   version;
   uint32_t   timestamp_offset;		/* Set to offset+1 of record */
   uint32_t   reclength;			/* Recordlength */
-  uint32_t   stored_rec_length;         /* Stored record length
-                                           (no generated-only virtual fields) */
+  uint32_t   stored_rec_length;         /* Stored record length*/
+  enum row_type row_type;		/* How rows are stored */
+
+  ha_rows min_rows;		/* create information */
+  ha_rows max_rows;		/* create information */
 
   StorageEngine *storage_engine;			/* storage engine plugin */
   inline StorageEngine *db_type() const	/* table_type for handler */
   {
     return storage_engine;
   }
-  enum row_type row_type;		/* How rows are stored */
   enum tmp_table_type tmp_table;
   enum ha_choice page_checksum;
 
   uint32_t ref_count;       /* How many Table objects uses this */
-  uint32_t open_count;			/* Number of tables in open list */
   uint32_t blob_ptr_size;			/* 4 or 8 */
   uint32_t key_block_size;			/* create key_block_size, if used */
   uint32_t null_bytes;
@@ -130,6 +128,13 @@
   bool waiting_on_cond;                 /* Protection against free */
 
   /*
+     Set of keys in use, implemented as a Bitmap.
+     Excludes keys disabled by ALTER Table ... DISABLE KEYS.
+  */
+  key_map keys_in_use;
+  key_map keys_for_keyread;
+
+  /*
     Set share's table cache key and update its db and table name appropriately.
 
     SYNOPSIS

=== modified file 'drizzled/tmp_table_param.h'
--- drizzled/tmp_table_param.h	2009-02-08 03:02:04 +0000
+++ drizzled/tmp_table_param.h	2009-05-21 16:13:03 +0000
@@ -35,6 +35,7 @@
   void operator=(Tmp_Table_Param &);
 
 public:
+  KEY *keyinfo;
   List<Item> copy_funcs;
   List<Item> save_copy_funcs;
   Copy_field *copy_field, *copy_field_end;
@@ -42,17 +43,16 @@
   unsigned char	    *group_buff;
   Item	    **items_to_copy;			/* Fields in tmp table */
   MI_COLUMNDEF *recinfo,*start_recinfo;
-  KEY *keyinfo;
   ha_rows end_write_records;
-  uint	field_count,sum_func_count,func_count;
+  uint32_t	field_count;
+  uint32_t	sum_func_count;
+  uint32_t	func_count;
   uint32_t  hidden_field_count;
-  uint	group_parts,group_length,group_null_parts;
-  uint	quick_group;
-  bool  using_indirect_summary_function;
-  /* If >0 convert all blob fields to varchar(convert_blob_length) */
-  uint32_t  convert_blob_length;
-  const CHARSET_INFO *table_charset;
+  uint32_t	group_parts,group_length,group_null_parts;
+  uint32_t	quick_group;
+  bool using_indirect_summary_function;
   bool schema_table;
+
   /*
     True if GROUP BY and its aggregate functions are already computed
     by a table access method (e.g. by loose index scan). In this case
@@ -60,7 +60,13 @@
     aggregate functions as normal functions.
   */
   bool precomputed_group_by;
+
   bool force_copy_fields;
+
+  /* If >0 convert all blob fields to varchar(convert_blob_length) */
+  uint32_t  convert_blob_length;
+
+  const CHARSET_INFO *table_charset;
   /*
     If true, create_tmp_field called from create_tmp_table will convert
     all BIT fields to 64-bit longs. This is a workaround the limitation
@@ -69,10 +75,15 @@
   bool bit_fields_as_long;
 
   Tmp_Table_Param()
-    :copy_field(0), group_parts(0),
-     group_length(0), group_null_parts(0), convert_blob_length(0),
-     schema_table(0), precomputed_group_by(0), force_copy_fields(0),
-     bit_fields_as_long(0)
+    :copy_field(0),
+    group_parts(0),
+    group_length(0),
+    group_null_parts(0),
+    schema_table(false),
+    precomputed_group_by(false),
+    force_copy_fields(false),
+    convert_blob_length(0),
+    bit_fields_as_long(false)
   {}
   ~Tmp_Table_Param()
   {

